package com.jcg;

import io.micronaut.core.type.Argument;
import io.micronaut.http.HttpRequest;
import io.micronaut.http.HttpResponse;
import io.micronaut.http.client.HttpClient;
import io.micronaut.http.client.annotation.Client;
import io.micronaut.test.extensions.junit5.annotation.MicronautTest;
import org.junit.jupiter.api.Test;

import jakarta.inject.Inject;
import java.util.List;
import static org.junit.jupiter.api.Assertions.assertEquals;
import static org.junit.jupiter.api.Assertions.assertNotNull;

@MicronautTest
class ProductControllerTest {

    @Inject
    @Client("/")
    HttpClient client;

    @Test
    void testGetProduct() {
        HttpRequest<String> request = HttpRequest.GET("/product");
        HttpResponse<Product> response = client.toBlocking().exchange(request, Product.class);

        assertEquals(200, response.getStatus().getCode());
        assertNotNull(response.body());
        assertEquals("Laptop", response.body().getName());
        assertEquals(1200.00, response.body().getPrice());
    }

    @Test
    void testGetAllProducts() {
        HttpRequest<String> request = HttpRequest.GET("/products");
        HttpResponse<List<Product>> response = client.toBlocking().exchange(request, Argument.listOf(Product.class));

        assertEquals(200, response.getStatus().getCode());
        assertNotNull(response.body());
        assertEquals(2, response.body().size());
        assertEquals("Laptop", response.body().get(0).getName());
        assertEquals(1200.00, response.body().get(0).getPrice());
        assertEquals("Smartphone", response.body().get(1).getName());
        assertEquals(800.00, response.body().get(1).getPrice());
    }

}
